
// return x*log(x)
inline Double llog(Double x)
{
  if(x==Double(0))
    return(Double(0));
  else
    return(x*log(x));
}

// return x*log(|x|)
inline Double lloga(Double x)
{
  if(x==Double(0))
    return(Double(0));
  else
    return(x*log(abs(x)));
}

// discontinuity of B0
inline Double DeltaB0(Double s, Double m1se, Double m2se)
{ if(s > sqr(sqrt(m1se)+sqrt(m2se)))
    return(sla(s,m1se,m2se)/s);
  else
    return(0);
}

// discontinuity of B0(s,m1s,m2s)-B0(s,0,0), above threshold
inline Double DeltaB0sub(Double s, Double m1se, Double m2se)
{ return((sqr(m1se-m2se)-2*s*(m1se+m2se))/(s*(sla(s,m1se,m2se)+s)));
}

// discontinuity of derivative of B0 with respect to m1s
inline Double DM1DeltaB0(Double s, Double m1se, Double m2se)
{ if(s > sqr(sqrt(m1se)+sqrt(m2se)))
    return((m1se-m2se-s)/(s*sla(s,m1se,m2se)));
  else
    return(0);
}

// discontinuity of derivative of B0(s,m1s,m2s)-B0(s,m1s,0) with respect to m1s,
//  above threshold
inline Double DM1DeltaB0sub(Double s, Double m1se, Double m2se)
{ return(4*m2se/((m1se-m2se-s)*sla(s,m1se,m2se)-la(s,m1se,m2se)));
}

// discontinuity of double derivative of B0 with respect to m1s
inline Double DM1DM1DeltaB0(Double s, Double m1se, Double m2se)
{ if(s > sqr(sqrt(m1se)+sqrt(m2se)))
    return((-4*m2se)/trip(sla(s,m1se,m2se)));
  else
    return(0);
}
