(* ------------------------------------------------------------- *)
(* uself.m                                                       *)
(* Ayres Freitas (afreitas@pitt.edu)			         *)
(* last revision 14.04.20                                        *)
(* ------------------------------------------------------------- *)
(* Mathematica file for subtraction of divergent pieces from     *)
(* 2- and 3-loop self-energy master integrals (Txx and Uxx);     *)
(* expansion in eps=(4-d)/2; and analytical formulae for         *)
(* certain subtraction terms                                     *)
(* ------------------------------------------------------------- *)
(* Reference:                                                    *)
(*   [2] = Bauberger, Freitas, Wiegand, arXiv:1908.09887         *)
(* ------------------------------------------------------------- *)

parsh = {m1s->$a1, m2s->$a2, m3s->$a3, m4s->$a4, m5s->$a5, m6s->$a6, m7s->$a7};
SetDirectory[DirectoryName[$InputFileName]];
(* need u4ax special cases for m1=m2, m3=m4 *)
u4ap = (<< ../zerosub/u4ap) /. parsh;
u4app = (<< ../zerosub/u4app) /. parsh;
u4a1p = (<< ../zerosub/u4a1p) /. parsh;
u4a30 = (<< ../zerosub/u4a30) /. parsh;
u4a3p = (<< ../zerosub/u4a3p) /. parsh;
u5ap = (<< ../zerosub/u5ap) /. parsh;
u5bp = (<< ../zerosub/u5bp) /. parsh;
u5cp = (<< ../zerosub/u5cp) /. parsh;
u5cp1e2 = (<< ../zerosub/u5cp_m1em2) /. parsh;
u6a0 = (<< ../zerosub/u6a0) /. parsh;
u6c0 = (<< ../zerosub/u6c0) /. parsh;
u6n0 = (<< ../zerosub/u6n0) /. parsh;
ResetDirectory[];

usrepl = {
  U4a[ps_,m1s_,m3s_,m6s_,m8s_] :>
   M1111[m1s,m3s,m6s,m8s] +
    ps*(u4ap /. {$a1->m1s, $a2->m3s, $a3->m6s, $a4->m8s}) +
    ps^2/2*(u4app /. {$a1->m1s, $a2->m3s, $a3->m6s, $a4->m8s}) +
    U4asub[ps,m1s,m3s,m6s,m8s],
  U5a[ps_,m1s_,m3s_,m5s_,m6s_,m7s_] :>
   U5[m6s,m7s,m1s,m3s,m5s] + 
    ps*(u5ap /. {$a2->m5s, $a3->m1s, $a4->m3s, $a5->m6s, $a6->m7s}) +
    B0[0,m1s,m3s]*(T3a[ps,m5s,m6s,m7s] - T3[m5s,m6s,m7s] - ps*DT3a0[m5s,m6s,m7s]) + 
    B0[0,m6s,m7s]*(T3a[ps,m5s,m1s,m3s] - T3[m5s,m1s,m3s] - ps*DT3a0[m5s,m1s,m3s]) + 
    U5asub[ps,m1s,m3s,m5s,m6s,m7s],
  U5b[ps_,m2s_,m3s_,m4s_,m6s_,m7s_] :>
   U5[m2s,m3s,m6s,m7s,m4s] + 
    ps*(u5bp /. {$a1->m4s, $a3->m6s, $a4->m7s, $a5->m2s, $a6->m3s}) +
    B0[m4s, m6s, m7s]*(T3a[ps, m2s, m3s, m4s] - T3[m2s, m3s, m4s] -
     ps*DT3a0[m2s, m3s, m4s]) + U5bsub[ps,m2s,m3s,m4s,m6s,m7s],
  U5c[ps_,m1s_,m2s_,m3s_,m6s_,m7s_] :>
   U5c0[m1s,m2s,m3s,m6s,m7s] +
    ps*(u5cp /. {$a1->m1s, $a2->m2s, $a3->m3s, $a4->m6s, $a5->m7s}) +
    T3a[m1s,m3s,m6s,m7s]*(B0[ps,m1s,m2s] - B0[0,m1s,m2s] - ps*DB0[0,m1s,m2s]) +
    U5csub[ps,m1s,m2s,m3s,m6s,m7s] /; m1s=!=m2s,
  U5c[ps_,m1s_,m1s_,m3s_,m6s_,m7s_] :>
   U5c0[m1s,m1s,m3s,m6s,m7s] +
    ps*(u5cp1e2 /. {$a1->m1s, $a3->m3s, $a4->m6s, $a5->m7s}) +
    T3a[m1s,m3s,m6s,m7s]*(B0[ps,m1s,m1s] - B0[0,m1s,m1s] - ps*DB0[0,m1s,m1s]) +
    U5csub[ps,m1s,m1s,m3s,m6s,m7s],
  U6a[ps_,m1s_,m3s_,m4s_,m5s_,m6s_,m7s_] :>
   U6a0[m4s,m5s,m1s,m3s,m6s,m7s] +
    B0[m4s,m6s,m7s]*(T4a[ps,m4s,m5s,m1s,m3s] - T12340[m4s,m5s,m1s,m3s]) +
    B0[m4s,m1s,m3s]*(T4a[ps,m4s,m5s,m6s,m7s] - T12340[m4s,m5s,m6s,m7s]) -
    B0[m4s,m1s,m3s]*B0[m4s,m6s,m7s]*(B0[ps,m4s,m5s] - B0[0,m4s,m5s]) +
    U6asub[ps,m1s,m3s,m4s,m5s,m6s,m7s],
  U6b[ps_,m1s_,m3s_,m4s_,m5s_,m6s_,m8s_] :>
   U6a0[m4s,m5s,m1s,m3s,m6s,m8s] +
    B0[m5s,m6s,m8s]*(T4a[ps,m4s,m5s,m1s,m3s] - T12340[m4s,m5s,m1s,m3s]) +
    B0[m4s,m1s,m3s]*(T4a[ps,m5s,m4s,m6s,m8s] - T12340[m5s,m4s,m6s,m8s]) -
    B0[m4s,m1s,m3s]*B0[m5s,m6s,m8s]*(B0[ps,m4s,m5s] - B0[0,m4s,m5s]) +
    U6bsub[ps,m1s,m3s,m4s,m5s,m6s,m8s],
  U6c[ps_,m1s_,m2s_,m3s_,m4s_,m6s_,m7s_] :>
   U6c0[m1s,m2s,m4s,m3s,m6s,m7s] +
    B0[m4s,m6s,m7s]*(T4a[ps,m1s,m2s,m3s,m4s] - T12340[m1s,m2s,m3s,m4s]) +
    T4a[m1s,m4s,m3s,m6s,m7s]*(B0[ps,m1s,m2s] - B0[0,m1s,m2s]) -
    B0[m1s,m3s,m4s]*B0[m4s,m6s,m7s]*(B0[ps,m1s,m2s] - B0[0,m1s,m2s]) +
    U6csub[ps,m1s,m2s,m3s,m4s,m6s,m7s],
  U6m[ps_,m1s_,m2s_,m3s_,m4s_,m6s_,m8s_] :>
    U6c0[m2s,m1s,m4s,m3s,m6s,m8s] +
     B0[0,m6s,m8s]*(T4a[ps,m1s,m2s,m3s,m4s] - T12340[m1s,m2s,m3s,m4s]) +
     T12340[0,0,m6s,m8s]*(B0[ps,m1s,m2s] - B0[0,m1s,m2s]) +
     U6msub[ps,m1s,m2s,m3s,m4s,m6s,m8s],
  U6n[ps_,m1s_,m2s_,m3s_,m6s_,m7s_,m8s_] :>
    U6n0[m1s,m2s,m7s,m8s,m3s,m6s] +
     B0[0,m3s,m6s]*(B0[ps,m1s,m2s]*B0[ps,m7s,m8s] - B0[0,m1s,m2s]*B0[0,m7s,m8s]) +
     T12340[0,0,m3s,m6s]*(B0[ps,m1s,m2s] + B0[ps,m7s,m8s] - 
     			   B0[0,m1s,m2s] - B0[0,m7s,m8s]) +
     U6nsub[ps,m1s,m2s,m3s,m6s,m7s,m8s],
  U7m[ps_,m1s_,m2s_,m3s_,m4s_,m5s_,m6s_,m8s_] :>
    B0[m5s,m6s,m8s]*T5a[ps,m1s,m2s,m3s,m4s,m5s] +
    U7msub[ps,m1s,m2s,m3s,m4s,m5s,m6s,m8s],
  U4a1[ps_,m1s_,m3s_,m6s_,m8s_] :>
   U4[m1s,m3s,m6s,m8s] +
    ps*(u4a1p /. {$a1->m1s, $a2->m3s, $a3->m6s, $a4->m8s}) +
    U4a1sub[ps,m1s,m3s,m6s,m8s],
  U4a2[ps_,m1s_,m3s_,m6s_,m8s_] :>
   U6n0[m1s,m1s,m3s,m3s,m6s,m8s] + U4a2sub[ps,m1s,m3s,m6s,m8s],
  U4a3[ps_,m1s_,m3s_,m6s_,m8s_] :>
   (u4a30 /. {$a1->m1s, $a2->m3s, $a3->m6s, $a4->m8s}) +
    ps*(u4a3p /. {$a1->m1s, $a2->m3s, $a3->m6s, $a4->m8s}) +
    U4a3sub[ps,m1s,m3s,m6s,m8s],
  U5a1[ps_,m1s_,m3s_,m5s_,m6s_,m7s_] :>
   U6a0[m5s,m5s,m1s,m3s,m6s,m7s] + 
    B0[0, m1s, m3s]*(T3a1[ps, m5s, m6s, m7s] - T1134[m5s, m6s, m7s]) +
    B0[0, m6s, m7s]*(T3a1[ps, m5s, m1s, m3s] - T1134[m5s, m1s, m3s]) +
    U5a1sub[ps,m1s,m3s,m5s,m6s,m7s],
  U5a2[ps_,m1s_,m3s_,m5s_,m6s_,m7s_] :>
   U6c0[m1s,m1s,m5s,m3s,m6s,m7s] + 
    B0[0, m6s, m7s]*(T3a1[ps, m1s, m3s, m5s] - T1134[m1s, m3s, m5s]) +
    U5a2sub[ps,m1s,m3s,m5s,m6s,m7s],
  U5b1[ps_,m2s_,m3s_,m4s_,m6s_,m7s_] :>	
   U6a0[m4s,m4s,m6s,m7s,m2s,m3s] +
    B0[m4s, m6s, m7s]*(T3a1[ps, m4s, m3s, m2s] - T1134[m4s, m3s, m2s]) +
    U5b1sub[ps,m2s,m3s,m4s,m6s,m7s],
  U5b2[ps_,m2s_,m3s_,m4s_,m6s_,m7s_] :>	
   U6c0[m2s,m2s,m4s,m3s,m6s,m7s] +
    B0[m4s, m6s, m7s]*(T3a1[ps, m2s, m3s, m4s] - T1134[m2s, m3s, m4s]) +
    U5b2sub[ps,m2s,m3s,m4s,m6s,m7s],
  U5c1[ps_,m1s_,m2s_,m3s_,m6s_,m7s_] :>
   U6n0[m1s,m2s,m7s,m7s,m3s,m6s] +
    T3a1[m1s,m7s,m6s,m3s]*(B0[ps,m1s,m2s] - B0[0,m1s,m2s]) +
    U5c1sub[ps,m1s,m2s,m3s,m6s,m7s],
  U6m1[ps_,m1s_,m2s_,m3s_,m4s_,m6s_,m8s_] :>
    DM4U6c0[m2s,m1s,m4s,m3s,m6s,m8s] +
     B0[0,m6s,m8s]*(T4a3[ps,m1s,m2s,m3s,m4s] - T123440[m1s,m2s,m4s,m3s]) +
     U6m1sub[ps,m1s,m2s,m3s,m4s,m6s,m8s],
  U6m3[ps_,m1s_,m2s_,m3s_,m4s_,m6s_,m8s_] :>
    DM1U6c0[m2s,m1s,m4s,m3s,m6s,m8s] +
     B0[0,m6s,m8s]*(T4a2[ps,m1s,m2s,m3s,m4s] - T112340[m2s,m1s,m3s,m4s]) +
     T12340[0,0,m6s,m8s]*(DM1B0[ps,m2s,m1s] - DM1B0[0,m2s,m1s]) +
     U6m3sub[ps,m1s,m2s,m3s,m4s,m6s,m8s],
  U6n2[ps_,m1s_,m2s_,m3s_,m6s_,m7s_,m8s_] :>
    DM1U6n0[m2s,m1s,m8s,m7s,m3s,m6s] +
     B0[0,m3s,m6s]*(DM1B0[ps,m2s,m1s]*B0[ps,m7s,m8s] - 
                    DM1B0[0,m2s,m1s]*B0[0,m7s,m8s]) +
     T12340[0,0,m3s,m6s]*(DM1B0[ps,m2s,m1s] - DM1B0[0,m2s,m1s]) +
     U6n2sub[ps,m1s,m2s,m3s,m6s,m7s,m8s],
  U5c0[m1s_,m2s_,m3s_,m4s_,m5s_] :>
   (M1111[m1s,m3s,m4s,m5s] - M1111[m2s,m3s,m4s,m5s])/(m1s - m2s) /; m1s=!=m2s,
  M1111[m1s_,m2s_,m3s_,m4s_] :> 2/(3*$D-8)*(m1s*U4[m1s,m2s,m3s,m4s] +
    m2s*U4[m2s,m3s,m4s,m1s] + m3s*U4[m3s,m4s,m1s,m2s] + m4s*U4[m4s,m1s,m2s,m3s]),
  U5c0[m1s_,m1s_,m3s_,m4s_,m5s_] :> U4[m1s,m3s,m4s,m5s],
  U6a0[m1s_,m2s_,m3s_,m4s_,m5s_,m6s_] :>
   (U5[m3s,m4s,m5s,m6s,m1s] - U5[m3s,m4s,m5s,m6s,m2s])/(m1s - m2s) /; m1s=!=m2s,
  U6a0[m1s_,m1s_,m3s_,m4s_,m5s_,m6s_] :>
   (u6a0 /. {$a1->m1s, $a3->m3s, $a4->m4s, $a5->m5s, $a6->m6s}),
  U6c0[m1s_,m2s_,m3s_,m4s_,m5s_,m6s_] :>
   (U5[m1s,m4s,m5s,m6s,m3s] - U5[m2s,m4s,m5s,m6s,m3s])/(m1s - m2s) /; m1s=!=m2s,
  U6c0[m1s_,m1s_,m3s_,m4s_,m5s_,m6s_] :>
   (u6c0 /. {$a1->m1s, $a3->m3s, $a4->m4s, $a5->m5s, $a6->m6s}),
  U6n0[m1s_,m2s_,m4s_,m5s_,m6s_,m7s_] :>
   (U5c0[m1s,m2s,m4s,m6s,m7s] - U5c0[m1s,m2s,m5s,m6s,m7s])/(m4s - m5s) /;
    m4s=!=m5s,
  U6n0[m1s_,m2s_,m4s_,m5s_,m6s_,m7s_] :>
   (U5c0[m4s,m5s,m1s,m6s,m7s] - U5c0[m4s,m5s,m2s,m6s,m7s])/(m1s - m2s) /;
    m1s=!=m2s,
  U6n0[m1s_,m1s_,m4s_,m4s_,m6s_,m7s_] :> 
   (u6n0 /. {$a1->m1s, $a4->m4s, $a6->m6s, $a7->m7s}),
  DM1U6c0[m1s_,m2s_,m3s_,m4s_,m5s_,m6s_] :>
   (U5[m2s,m4s,m5s,m6s,m3s] - U5[m1s,m4s,m5s,m6s,m3s])/(m1s - m2s)^2 +
    U6c0[m1s,m1s,m3s,m4s,m5s,m6s]/(m1s - m2s) /; m1s=!=m2s,
  DM4U6c0[m1s_,m2s_,m3s_,m4s_,m5s_,m6s_] :>
   (U6c0[m4s,m4s,m3s,m1s,m5s,m6s] - U6c0[m4s,m4s,m3s,m2s,m5s,m6s])/
    (m1s - m2s) /; m1s=!=m2s,
  DM1U6n0[m1s_,m2s_,m4s_,m5s_,m6s_,m7s_] :>
   (U5c0[m4s,m5s,m2s,m6s,m7s] - U5c0[m4s,m5s,m1s,m6s,m7s])/(m1s - m2s)^2 +
    U6n0[m1s,m1s,m4s,m5s,m6s,m7s]/(m1s - m2s) /; m1s=!=m2s
};

tsrepl = {
(*  DB0[ps_, m1s_, m2s_] :> 1/lambda[ps,m1s,m2s] *
                    (((m1s-m2s)^2/ps*(2-$D)/2 - ps*(4-$D)/2 + m1s+m2s) *
                        B0[ps,m1s,m2s] -
                     m2s*(ps+m1s-m2s)/ps * ($D/2-1) B0[0,0,m2s] -
                     m1s*(ps+m2s-m1s)/ps * ($D/2-1) B0[0,0,m1s]) /;
                        (ps=!=0 && Simplify[lambda[m1s,m2s,ps]]=!=0),
  DB0[ms_, 0, ms_] :> -($D-2)/($D-3) A0[ms]/(4 ms^2) /; ms=!=0, *)
  DB0[0, ms_, ms_] :> -1/6*($D/2-1)*($D/2-2)*A0[ms]/ms^2 /; ms=!=0,
  DB0[0, m1s_,m2s_] :> (m2s A0[m1s] - m1s A0[m2s] +
                     (4-$D)/$D (m1s A0[m1s] - m2s A0[m2s])) /
                    (m1s - m2s)^3 /; m1s=!=m2s,
  DM1B0[ps_,m1s_,m2s_] :> 1/lambda[m1s,m2s,ps] *
   ((ps+m2s-m1s)*(3-$D)*B0[ps,m1s,m2s] +
    (ps-m1s-m2s)*B0[0,m1s,m1s] + 2*m2s*B0[0,m2s,m2s]) /;
       (ps=!=0 && lambda[m1s,m2s,ps]=!=0),
  DM1B0[ms_,0,ms_] :> ($D-2)/(4*($D-5))*A0[ms]/ms^2 /; ms=!=0,
  DM1B0[ms_,ms_,0] :> ($D-2)/4*A0[ms]/ms^2 /; ms=!=0,
  DM1B0[0,m1s_,m2s_] :>
    (1/(m1s-m2s)^2 * (A0[m2s] - A0[m1s]) +
     1/(m1s-m2s) * B0[0,m1s,m1s]) /; m1s=!=m2s,
  DM1B0[0,ms_,ms_] :> 1/2*($D/2-1)*($D/2-2)*A0[ms]/ms^2 /; ms=!=0,
  B0[0,0,0] -> 0,
  B0[0,ms_,ms_] :> ($D/2-1)*A0[ms]/ms /; ms=!=0,
  B0[0,m1s_,m2s_] :> (A0[m1s] - A0[m2s])/(m1s - m2s) /; m1s=!=m2s,
  B0[bargs__] :> 1/$eps + B0fin[bargs] + $eps*B0delta[bargs] +
  		  $eps^2*B0deltadelta[bargs],
  T3a[ps_,0,0,0] :> -$lpfac^2 * ps^(1-2*$eps) * Exp[-I*Pi*(1-2*$eps)] *
	 		Gamma[1-$eps]^3*Gamma[-1+2*$eps]/Gamma[3-3*$eps],
  T3a[ps_,ms__] :> T3[ms] + ps*DT3a0[ms] + T3asub[ps,ms] + 
  		     $eps*T3adelta[ps,ms],
  DT3a0[m2s_,m3s_,m4s_] :> 2/$D*((2-$D/2)*T1134[m2s,m3s,m4s] +
				  m2s*2*T112340[m2s,m2s,m3s,m4s]),
  T3a1[ps_,0,0,0] :> $lpfac^2 * ps^(-2*$eps) * Exp[-I*Pi*(-2*$eps)] *
                     Gamma[1-$eps]^2*Gamma[-$eps]*Gamma[2*$eps]/Gamma[2-3*$eps],
  T3a1[ps_,ms__] :> T3a1sub[ps,ms] + T1134[ms] + $eps*T3a1delta[ps,ms],
  T4a[ps_,0,0,0,0] :> -$lpfac^2 * ps^(-2*$eps) * Exp[-I*Pi*(-2*$eps)] *
	 		Gamma[1-$eps]^3*Gamma[-1+2*$eps]/($eps*Gamma[2-3*$eps]),
  T4a[ps_,0,m2_,0,0] :> $lpfac^2 * Gamma[1+$eps]^2 * (1/(2*$eps^2) +
  	   (5/2 - Log[m2] + (1/xx-1)*Log0[1-xx])/$eps +
	    + 19/2 + Pi^2/6 + Log[m2]^2
            - (5 + 2*(1-xx)/xx Log0[1-xx]) * Log[m2]
            + 5*(1-xx)/xx Log0[1-xx] + (2-1/xx) PolyLog[2,xx]
            + 2*(1-1/xx) Log0[1-xx]^2 +
	    $eps*T4am1zdelta[ps,m2]/. xx->ps/m2),
  T4a[ps_,m1_,m2_,m3_,m4_] :> T12340[m1,m2,m3,m4] + 
  	  B0[m1,m3,m4]*(B0[ps,m1,m2] - B0[0,m1,m2]) + T4asub[ps,m1,m2,m3,m4] +
	  $eps*T4adelta[ps,m1,m2,m3,m4],
  T4a1[ps_,0,0,0,0] :> -$lpfac^2 * ps^(-1-2*$eps) * Exp[-I*Pi*(-1-2*$eps)] *
          Gamma[1-$eps]^3*Gamma[-1+2*$eps]/($eps*(1+$eps)*Gamma[1-3*$eps]),
  T4a1[ps_,m1_,m2_,m3_,m4_] :> B0[m1,m3,m4]*DM1B0[ps,m1,m2] +
  	  T4a1sub[ps,m1,m2,m3,m4] + $eps*T4a1delta[ps,m1,m2,m3,m4],
  T4a2[ps_,m1_,m2_,m3_,m4_] :>
   ((2*m3*(-m1 + m3 - m4)*B0[0,m3,m3]*B0[ps,m1,m2])/lambda[m1,m3,m4] - 
     (2*(m1 + m3 - m4)*m4*B0[0,m4,m4]*B0[ps,m1,m2])/lambda[m1,m3,m4] - 
     T3a1[ps,m2,m3,m4] - (2*m3*(-m1 + m3 - m4)*T3a1[ps,m3,m2,m4])/
      lambda[m1,m3,m4] + (2*(m1 + m3 - m4)*m4*T3a1[ps,m4,m2,m3])/lambda[m1,m3,m4] + 
     ((2*(-(m3 - m4)^2 + m1*(m3 + m4))*(-3 + $D) + lambda[m1,m3,m4]*(-7 + 2*$D))*
       T4a[ps,m1,m2,m3,m4])/lambda[m1,m3,m4] - 2*m1*T4a1[ps,m1,m2,m3,m4])/
    (m1 + m2 - ps) /; (lambda[m1,m3,m4]=!=0 && m1+m2=!=ps),
  T4a3[ps_,m1_,m2_,m3_,m4_] :>
   (-((-m1 + m3 + m4)*B0[0,m3,m3]*B0[ps,m1,m2]) + 
     2*m4*B0[0,m4,m4]*B0[ps,m1,m2] + (-m1 + m3 + m4)*
      T3a1[ps,m3,m2,m4] - 2*m4*T3a1[ps,m4,m2,m3] - 
     (m1 - m3 + m4)*(-3 + $D)*T4a[ps,m1,m2,m3,m4])/lambda[m1,m3,m4] /; 
    (lambda[m1,m3,m4]=!=0),
  T123440[m1_,m2_,m3_,m4_] :> 
         (T12340[m4,m4,m1,m3] - T12340[m4,m4,m2,m3])/(m1-m2) /; m1=!=m2,
  T112340[m1_,m2_,m3_,m4_] :> 
	 (T12340[m1,m1,m3,m4] - T12340[m1,m2,m3,m4])/(m1-m2) /; m1=!=m2,
  T112340[m1_,m1_,0,0] :> 
	  (($D-4)*($D-3)*T3[m1,0,0])/(2*m1^2) /; m1=!=0,
  T112340[m1_,m1_,0,m1_] :> 
	  (($D-6)*($D-4)*($D-2)*A0[m1]^2)/(16*m1^3*($D-5)) /; m1=!=0,
  T112340[m1_,m1_,m1_,0] :> 
	  (($D-6)*($D-4)*($D-2)*A0[m1]^2)/(16*m1^3*($D-5)) /; m1=!=0,
  T112340[m1_,m1_,m3_,m4_] :>
	-1/(2*m1*lambda[m1,m3,m4])*(
	 (2*lambda[m1,m3,m4] + (m1-m3)*(m1+m3-m4) + (m1-m4)*(m1-m3+m4) -
	  $D*m1*(m1-m3-m4))*T12340[m1,m1,m3,m4] +
	 m4*(m1+m3-m4)*(B0[0,m1,m1]*B0[0,m4,m4] - T12340[m4,m4,m3,m1]) +
	 m3*(m1-m3+m4)*(B0[0,m1,m1]*B0[0,m3,m3] - T12340[m3,m3,m4,m1])) /; 
       (m1=!=0 && lambda[m1,m3,m4]=!=0),
  T1134[m1_,m3_,m4_] :> T12340[m1,m1,m3,m4],
  T12340[m1_,m1_,0,m1_] :> T12340[m1,m1,m1,0],
  T12340[0,0,0,0] -> 0, 
  T12340[m1_,m1_,m1_,0] :> (($D-3) T3[m1,m1,0] +
 				 A0[m1] B0[0,m1,m1])/(4 m1) /; m1=!=0,
  T12340[0,0,m3_,m3_] :> ($D-2)/($D-5) * A0[m3]^2/(4 m3^2) /; m3=!=0,
  T12340[0,0,m3_,m4_] :> (($D-2)*A0[m3]*A0[m4] - 
       			  (m3+m4)*($D-3)*T3[m3,m4,0])/(m3-m4)^2 /; m3=!=m4,
  T12340[m1_,m1_,m3_,m4_] :> ((m1-m3-m4)*(3-$D) * T3[m1,m3,m4] +
       ($D/2-1) * (A0[m1] (A0[m3]+A0[m4]) - 2 A0[m3] A0[m4]) -
       (m3-m4) (A0[m3]-A0[m4]) B0[0,m1,m1]) / (-(m1-m3-m4)^2 + 4 m3 m4) /;
	     				(-(m1-m3-m4)^2 + 4 m3 m4) =!= 0,
  T12340[m1_,m2_,m3_,m4_] :> (T3[m1,m3,m4] - T3[m2,m3,m4])/(m1-m2) 
};
